==> haskell-test-framework-hunit-0.3.0.2-1025-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-8Pv7GyOwk1i7Fl8JHDa038
key:                  test-framework-hunit-0.3.0.2-8Pv7GyOwk1i7Fl8JHDa038
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  3150c7638a477523ede0ef7891d64d36
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-8Pv7GyOwk1i7Fl8JHDa038
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-8SApKo32kCGFbmigUnAEg9

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-1029-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-EedQhJEGlXLGUOgPHhIaG
key:                  test-framework-hunit-0.3.0.2-EedQhJEGlXLGUOgPHhIaG
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  2af5a45ba1ed9317476884efb81a2db6
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-EedQhJEGlXLGUOgPHhIaG
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    test-framework-0.8.2.2-K2ylRhrtjSj1DiAKcEz4dn

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
